@@ -1,7 +1,7 @@
-from gql import gql
-#######################################################
-####                    env vars                   ####
-#######################################################
+#   ___  _ __  __   __ __   __  __ _  _ __  ___
+#  / _ \| '_ \ \ \ / / \ \ / / / _` || '__|/ __|
+# |  __/| | | | \ V /   \ V / | (_| || |   \__ \
+#  \___||_| |_|  \_/     \_/   \__,_||_|   |___/
 
 gql_get_global_env_vars = """
   {
@@ -70,9 +70,13 @@ gql_create_project_env_var = """
   }}
 """
 
-###########################################################
-####                    repositories                   ####
-###########################################################
+#                                 _  _                 _
+#  _ __   ___  _ __    ___   ___ (_)| |_   ___   _ __ (_)  ___  ___
+# | '__| / _ \| '_ \  / _ \ / __|| || __| / _ \ | '__|| | / _ \/ __|
+# | |   |  __/| |_) || (_) |\__ \| || |_ | (_) || |   | ||  __/\__ \
+# |_|    \___|| .__/  \___/ |___/|_| \__| \___/ |_|   |_| \___||___/
+#             |_|
+
 
 gql_get_repositories_info = """
   {
@@ -97,9 +101,13 @@ gql_get_technologies = """
 }
 """
 
-#######################################################
-####                    projects                   ####
-#######################################################
+#                        _              _
+#  _ __   _ __   ___    (_)  ___   ___ | |_  ___
+# | '_ \ | '__| / _ \   | | / _ \ / __|| __|/ __|
+# | |_) || |   | (_) |  | ||  __/| (__ | |_ \__ \
+# | .__/ |_|    \___/  _/ | \___| \___| \__||___/
+# |_|                 |__/
+
 
 gql_get_projects_info = """
   {
@@ -131,8 +139,7 @@ gql_get_project_technologies = """
    technologiesByCategory(projectId: "{0}"){{
       jobCategory,
       technologies{{
-        id,
-        label
+        id
         }}
    }}
 }} 
@@ -183,9 +190,13 @@ mutation {{
 }}
 """
 
-#######################################################
-####                      jobs                     ####
-#######################################################
+#    _         _
+#   (_)  ___  | |__   ___
+#   | | / _ \ | '_ \ / __|
+#   | || (_) || |_) |\__ \
+#  _/ | \___/ |_.__/ |___/
+# |__/
+
 
 gql_get_project_jobs = """
   {{
@@ -216,8 +227,7 @@ gql_get_project_jobs = """
       }},
       category,
       technology {{
-        id,
-        label
+        id
       }},
       isScheduled,
       cronScheduling,
@@ -263,8 +273,7 @@ gql_get_project_job = """
       }},
       category,
       technology {{
-        id,
-        label
+        id
       }},
       isScheduled,
       cronScheduling,
@@ -357,7 +366,10 @@ gql_create_job = '{{"operationName": "createJobMutation",\
                        }},\
                        "file":null\
                    }},\
-                   "query": "mutation createJobMutation($job: JobInput!, $jobVersion: JobVersionInput!, $file: Upload) {{\\n  createJob(job: $job, jobVersion: $jobVersion, file: $file) {{\\n    id\\n    versions {{\\n      number\\n      __typename\\n    }}\\n    __typename\\n  }}\\n}}\\n"}}'
+                   "query": "mutation createJobMutation($job: JobInput!, $jobVersion: JobVersionInput!, $file: Upload) \
+                   {{\\n  createJob(job: $job, jobVersion: $jobVersion, file: $file) \
+                   {{\\n    id\\n    versions {{\\n      number\\n      __typename\\n    }}\\n   \
+                    __typename\\n  }}\\n}}\\n"}}'
 
 gql_extra_technology = '"extraTechnology": {{\
                            "language": "{0}",\
@@ -372,9 +384,12 @@ gql_delete_job = """
   }}
 """
 
-#######################################################
-####                      apps                     ####
-#######################################################
+#   __ _  _ __   _ __   ___
+#  / _` || '_ \ | '_ \ / __|
+# | (_| || |_) || |_) |\__ \
+#  \__,_|| .__/ | .__/ |___/
+#        |_|    |_|
+
 
 gql_get_project_web_apps = """
   {{
@@ -397,8 +412,7 @@ gql_get_project_web_apps = """
       }},
       category,
       technology {{
-        id,
-        label
+        id
       }},
       isScheduled,
       cronScheduling,
@@ -436,8 +450,7 @@ get_project_web_app = """
       }},
       category,
       technology {{
-        id,
-        label
+        id
       }},
       isScheduled,
       cronScheduling,
@@ -454,7 +467,6 @@ get_project_web_app = """
   }}
   """
 
-
 gql_get_project_app = """
   {{
     app(id: "{0}"){{
@@ -475,9 +487,12 @@ gql_get_project_app = """
   }}
   """
 
-#######################################################
-####                   pipelines                   ####
-#######################################################
+#         _               _  _
+#  _ __  (_) _ __    ___ | |(_) _ __    ___  ___
+# | '_ \ | || '_ \  / _ \| || || '_ \  / _ \/ __|
+# | |_) || || |_) ||  __/| || || | | ||  __/\__ \
+# | .__/ |_|| .__/  \___||_||_||_| |_| \___||___/
+# |_|       |_|
 
 gql_get_pipelines = """
   query{{
@@ -558,15 +573,6 @@ gql_edit_pipeline = """
   }}
 """
 
-gql_get_pipeline_instance = """
-  query{{
-    pipelineInstance(id: "{0}"){{
-      id,
-      status
-    }}
-  }}
-  """
-
 gql_run_pipeline = """
   mutation{{
     runPipeline(pipelineId: "{0}"){{
@@ -597,4 +603,4 @@ gql_get_pipeline_instance = """
           endTime
       }}
   }}
-"""
\ No newline at end of file
+"""
