@@ -8,6 +8,7 @@ import time
 import re
 from pathlib import Path
 
+from gql import gql
 from gql import Client
 from gql.transport.requests import RequestsHTTPTransport
 
@@ -28,18 +29,13 @@ class SaagieApi:
         url_saagie : str
             platform base URL (eg: https://saagie-workspace.prod.saagie.io)
         id_platform : int or str
-            Platform Id (you can find it in the URL after the '/platform/' when
-            you are on your own platform (eg, the platform'id is 6 in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/))
+            Platform Id  (see README on how to find it)
         user : str
             username to login with
         password : str
             password to login with
         realm : str
-            Saagie realm, which is the prefix that was determined during Saagie
-            installation. One can find it in the base url before the first '-'
-            (eg, the platform's realm is 'saagie' in
-            https://saagie-workspace.prod.saagie.io)
+            Saagie realm  (see README on how to find it)
         """
         if not url_saagie.endswith('/'):
             url_saagie += '/'
@@ -95,7 +91,7 @@ class SaagieApi:
             password to login with
         """
         url_regex = re.compile(
-            "(https:\/\/(\w+)-(?:\w|\.)+)\/projects\/platform\/(\d+)")
+            r"(https:\/\/(\w+)-(?:\w|\.)+)\/projects\/platform\/(\d+)")
         m = url_regex.match(url_saagie_platform)
         if bool(m):
             url_saagie = m.group(1)
@@ -111,7 +107,7 @@ class SaagieApi:
     # ######################################################
 
     def get_global_env_vars(self):
-        """Get global environmnet variables
+        """Get global environment variables
         NB: You can only list environment variables if you have at least the
         viewer role on the platform
 
@@ -189,10 +185,7 @@ class SaagieApi:
         Parameters
         ----------
         project_id : str
-            UUID of your project. Can be found in the project URL after the
-            '/project' (eg: the project UUID is
-            '8321e13c-892a-4481-8552-5be4b6cc5df4' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/jobs)
+            UUID of your project (see README on how to find it)
 
         Returns
         -------
@@ -209,10 +202,7 @@ class SaagieApi:
         Parameters
         ----------
         project_id : str
-            UUID of your project. Can be found in the project URL after the
-            '/project' (eg: the project UUID is
-            '8321e13c-892a-4481-8552-5be4b6cc5df4' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/jobs)
+            UUID of your project (see README on how to find it)
         name : str
             Name of the environment variable to create
         value : str
@@ -242,10 +232,7 @@ class SaagieApi:
         Parameters
         ----------
         project_id : str
-            UUID of your project. Can be found in the project URL after the
-            '/project' (eg: the project UUID is
-            '8321e13c-892a-4481-8552-5be4b6cc5df4' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/jobs)
+            UUID of your project (see README on how to find it)
         name : str
             Name of the environment variable to delete inside the given project
 
@@ -257,7 +244,7 @@ class SaagieApi:
         Raises
         ------
         ValueError
-            When the given name doesn't correspond to an existing environmnent
+            When the given name doesn't correspond to an existing environment
             variable inside the given project
         """
         project_envs = self.get_project_env_vars(project_id)
@@ -312,10 +299,7 @@ class SaagieApi:
         Parameters
         ----------
         project_id : str
-            UUID of your project. Can be found in the project URL after the
-            '/project' (eg: the project UUID is
-            '8321e13c-892a-4481-8552-5be4b6cc5df4' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/jobs)
+            UUID of your project (see README on how to find it)
 
         Returns
         -------
@@ -331,10 +315,7 @@ class SaagieApi:
         Parameters
         ----------
         project_id : str
-            UUID of your project. Can be found in the project URL after the
-            '/project' (eg: the project UUID is
-            '8321e13c-892a-4481-8552-5be4b6cc5df4' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/jobs)
+            UUID of your project (see README on how to find it)
 
         Returns
         -------
@@ -396,10 +377,12 @@ class SaagieApi:
         # Keep only JobTechnologies (discarding AppTechnologies) of main
         # technology repository (Saagie repository)
         repositories = self.get_repositories_info()['repositories']
+        technologies = []
         for repo in repositories:
             if repo['name'] == 'Saagie':
                 technologies = [techno for techno in repo['technologies']
-                                if techno['__typename'] == 'JobTechnology' or (techno['__typename'] == 'SparkTechnology')]
+                                if
+                                techno['__typename'] == 'JobTechnology' or (techno['__typename'] == 'SparkTechnology')]
 
         # Generate the technology graphQL string only with technologies id
         technologies = [f'{{id: "{tech["id"]}"}}' for tech in technologies]
@@ -421,10 +404,7 @@ class SaagieApi:
         Parameters
         ----------
         project_id : str
-            UUID of your project. Can be found in the project URL after the
-            '/project' (eg: the project UUID is
-            '8321e13c-892a-4481-8552-5be4b6cc5df4' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/jobs)
+            UUID of your project (see README on how to find it)
 
         Returns
         -------
@@ -446,10 +426,7 @@ class SaagieApi:
         Parameters
         ----------
         project_id : str
-            UUID of your project. Can be found in the project URL after the
-            '/project/' (eg: the project UUID is
-            '8321e13c-892a-4481-8552-5be4b6cc5df4' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/jobs)
+            UUID of your project (see README on how to find it)
         instances_limit : int, optional
             Maximum limit of instances to fetch per job. Fetch from most recent
             to oldest
@@ -459,7 +436,7 @@ class SaagieApi:
         dict
             Dict of jobs information
         """
-        instances_limit_request =  f" (limit: {str(instances_limit)})" if instances_limit!=-1 else ""
+        instances_limit_request = f" (limit: {str(instances_limit)})" if instances_limit != -1 else ""
         query = gql(gql_get_project_jobs.format(project_id, instances_limit_request))
         return self.client.execute(query)
 
@@ -469,9 +446,7 @@ class SaagieApi:
         Parameters
         ----------
         job_id : str
-            UUID of your job. Can be found in the project URL after the '/job/'
-            (eg: the job UUID is 'a85ac3db-bca1-4f15-b8f7-44731fba874b' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/job/a85ac3db-bca1-4f15-b8f7-44731fba874b)
+            UUID of your job (see README on how to find it)
 
         Returns
         -------
@@ -487,10 +462,7 @@ class SaagieApi:
         Parameters
         ----------
         job_instance_id : str
-            UUID of your job instance. Can be found in the job instance URL
-            after the '/instances/' (eg: the job instance UUID is
-            '6ff448ae-3770-4639-b0f8-079e5c614ab6' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/job/a85ac3db-bca1-4f15-b8f7-44731fba874b/instances/6ff448ae-3770-4639-b0f8-079e5c614ab6)
+            UUID of your job instance (see README on how to find it)
 
         Returns
         -------
@@ -506,9 +478,7 @@ class SaagieApi:
         Parameters
         ----------
         job_id : str
-            UUID of your job. Can be found in the project URL after the '/job/'
-            (eg: the job UUID is 'a85ac3db-bca1-4f15-b8f7-44731fba874b' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/job/a85ac3db-bca1-4f15-b8f7-44731fba874b)
+            UUID of your job (see README on how to find it)
 
         Returns
         -------
@@ -525,13 +495,11 @@ class SaagieApi:
         Parameters
         ----------
         job_id : str
-            UUID of your job. Can be found in the project URL after the '/job/'
-            (eg: the job UUID is 'a85ac3db-bca1-4f15-b8f7-44731fba874b' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/job/a85ac3db-bca1-4f15-b8f7-44731fba874b)
+            UUID of your job (see README on how to find it)
         freq : int, optional
             Seconds to wait between two state checks
         timeout : int, optional
-            Seconds before timeout for a status'check call
+            Seconds before timeout for a status check call
 
         Returns
         -------
@@ -567,10 +535,7 @@ class SaagieApi:
         Parameters
         ----------
         job_instance_id : str
-            UUID of your job instance. Can be found in the job instance URL
-            after the '/instances/' (eg: the job instance UUID is
-            '6ff448ae-3770-4639-b0f8-079e5c614ab6' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/job/a85ac3db-bca1-4f15-b8f7-44731fba874b/instances/6ff448ae-3770-4639-b0f8-079e5c614ab6)
+            UUID of your job instance (see README on how to find it)
 
         Returns
         -------
@@ -601,6 +566,7 @@ class SaagieApi:
 
     def create_job(self, job_name, project_id, file=None, description='',
                    category='Processing', technology='python',
+                   technology_catalog='Saagie',
                    runtime_version='3.6',
                    command_line='python {file} arg1 arg2', release_note='',
                    extra_technology='', extra_technology_version=''):
@@ -618,18 +584,13 @@ class SaagieApi:
           See https://github.com/graphql-python/gql/issues/68 to follow this
           work.
         - Tested with python and spark jobs
-        - In case of multiple technologies with the same name (if they're coming from different
-          catalogs), the first one configured, in the catalog order, will be fetched
 
         Parameters
         ----------
         job_name : str
             Name of the job. Must not already exist in the project
         project_id : str
-            UUID of your project. Can be found in the project URL after the
-            '/project' (eg: the project UUID is
-            '8321e13c-892a-4481-8552-5be4b6cc5df4' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/jobs)
+            UUID of your project (see README on how to find it)
         file : str, optional
             Local path of the file to upload
         description : str, optional
@@ -640,6 +601,8 @@ class SaagieApi:
         technology : str, optional
             Technology label of the job to create. See self.get_technologies()
             for a list of available technologies
+        technology_catalog : str, optional
+            Technology catalog containing the technology to use for this job
         runtime_version : str, optional
             Technology version of the job
         command_line : str, optional
@@ -665,17 +628,37 @@ class SaagieApi:
         """
         file = Path(file)
 
-        technology = technology.lower()
-        technologies = self.get_project_technologies(project_id)['technologiesByCategory']
-        technologies_for_category = [tech['technologies'] for tech in technologies if tech['jobCategory'] == category][
-            0]
-        job_technology = [tech['id'] for tech in technologies_for_category
-                          if tech['label'].lower() == technology]
-        if not job_technology:
+        technologies_for_project = self.get_project_technologies(project_id)['technologiesByCategory']
+        technologies_for_project_and_category = [
+            tech['id'] for tech in
+            [
+                tech['technologies'] for tech in technologies_for_project
+                if tech['jobCategory'] == category
+            ][0]
+        ]
+        all_technologies_in_catalog = [
+            catalog['technologies'] for catalog in self.get_repositories_info()['repositories']
+            if catalog['name'] == technology_catalog
+        ]
+        if not all_technologies_in_catalog:
             raise RuntimeError(
-                f"Technology {technology} does not exist in the target project {project_id} for the {category}category")
+                f"Catalog {technology_catalog} does not exist or does not contain technologies")
+
+        technology_in_catalog = [tech['id'] for tech in
+                                 all_technologies_in_catalog[0]
+                                 if tech["label"].lower() == technology.lower()]
+
+        if not technology_in_catalog:
+            raise RuntimeError(
+                f"Technology {technology} does not exist in the catalog {technology_catalog}")
+
+        if technology_in_catalog[0] not in technologies_for_project_and_category:
+            raise RuntimeError(
+                f"Technology {technology} does not exist in the target project {project_id} "
+                f"for the {category} category "
+                f"and for the {technology_catalog} catalog")
         else:
-            technology_id = job_technology[0]
+            technology_id = technology_in_catalog[0]
 
         if extra_technology != '':
             extra_tech = gql_extra_technology.format(extra_technology,
@@ -685,43 +668,43 @@ class SaagieApi:
 
         url = self.url_saagie + self.suffix_api + 'platform/'
         url += str(self.id_platform) + "/graphql"
-        
+
         if file:
             file = Path(file)
-            #logging.debug("Creating jobs with archive ...")
+            # logging.debug("Creating jobs with archive ...")
             with file.open(mode='rb') as f:
                 files = {
                     '1': (file.name, f),
                     'operations': (None, gql_create_job.format(job_name,
-                                                            project_id,
-                                                            description,
-                                                            category,
-                                                            technology_id,
-                                                            runtime_version,
-                                                            command_line,
-                                                            release_note,
-                                                            extra_tech)),
+                                                               project_id,
+                                                               description,
+                                                               category,
+                                                               technology_id,
+                                                               runtime_version,
+                                                               command_line,
+                                                               release_note,
+                                                               extra_tech)),
                     'map': (None, '{ "1": ["variables.file"] }'),
                 }
                 response = requests.post(url,
-                                        files=files,
-                                        auth=self.auth,
-                                        verify=False)
+                                         files=files,
+                                         auth=self.auth,
+                                         verify=False)
         else:
             payload_str = gql_create_job.format(job_name,
-                                        project_id,
-                                        description,
-                                        category,
-                                        technology_id,
-                                        runtime_version,
-                                        command_line,
-                                        release_note,
-                                        extra_tech)
+                                                project_id,
+                                                description,
+                                                category,
+                                                technology_id,
+                                                runtime_version,
+                                                command_line,
+                                                release_note,
+                                                extra_tech)
             payload = json.loads(payload_str)
             response = requests.post(url,
-                                        json=payload,
-                                        auth=self.auth,
-                                        verify=False)
+                                     json=payload,
+                                     auth=self.auth,
+                                     verify=False)
 
         if response:
             return json.loads(response.content)
@@ -735,9 +718,7 @@ class SaagieApi:
         Parameters
         ----------
         job_id : str
-            UUID of your job. Can be found in the project URL after the '/job/'
-            (eg: the job UUID is 'a85ac3db-bca1-4f15-b8f7-44731fba874b' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/job/a85ac3db-bca1-4f15-b8f7-44731fba874b)
+            UUID of your job (see README on how to find it)
 
         Returns
         -------
@@ -762,10 +743,7 @@ class SaagieApi:
         Parameters
         ----------
         project_id : str
-            UUID of your project. Can be found in the project URL after the
-            '/project' (eg: the project UUID is
-            '8321e13c-892a-4481-8552-5be4b6cc5df4' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/jobs)
+            UUID of your project (see README on how to find it)
         instances_limit : int, optional
             Maximum limit of instances to fetch per webapp. Fetch from most
             recent to oldest
@@ -775,13 +753,13 @@ class SaagieApi:
         dict
             Dict of webApp information
         """
-        regex_error_missing_technology = "io\.saagie\.projectsandjobs\.domain\.exception\.NonExistingTechnologyException: Technology \S{8}-\S{4}-\S{4}-\S{4}-\S{12} does not exist"
-        instances_limit_request =  f" (limit: {str(instances_limit)})" if instances_limit!=-1 else ""
-        
+        regex_error_missing_technology = r"io\.saagie\.projectsandjobs\.domain\.exception\.NonExistingTechnologyException: Technology \S{8}-\S{4}-\S{4}-\S{4}-\S{12} does not exist"
+        instances_limit_request = f" (limit: {str(instances_limit)})" if instances_limit != -1 else ""
+
         query = gql(gql_get_project_web_apps.format(project_id,
                                                     instances_limit_request))
-        result = self.client._get_result(query) 
-        
+        result = self.client.execute(query)
+
         if result.errors:
             # Matching errors with error missing technology message
             errors_matching = [re.fullmatch(regex_error_missing_technology, e['message']) for e in result.errors]
@@ -814,9 +792,7 @@ class SaagieApi:
         Parameters
         ----------
         app_id : str
-            UUID of your app. Can be found in the project URL after the '/app/'
-            (eg: the app UUID is '02c01d47-8a29-47d0-a53c-235add43c885' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/app/02c01d47-8a29-47d0-a53c-235add43c885)
+            UUID of your app (see README on how to find it)
 
         Returns
         -------
@@ -835,10 +811,7 @@ class SaagieApi:
         Parameters
         ----------
         project_id : str
-            UUID of your project. Can be found in the project URL after the
-            '/project' (eg: the project UUID is
-            '8321e13c-892a-4481-8552-5be4b6cc5df4' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/jobs)
+            UUID of your project (see README on how to find it)
         instances_limit : int, optional
             Maximum limit of instances to fetch per pipelines. Fetch from most
             recent to oldest
@@ -848,7 +821,7 @@ class SaagieApi:
         Dict
             Dict of pipelines information
         """
-        instances_limit_request =  f" (limit: {str(instances_limit)})" if instances_limit!=-1 else ""
+        instances_limit_request = f" (limit: {str(instances_limit)})" if instances_limit != -1 else ""
         query = gql(gql_get_pipelines.format(project_id, instances_limit_request))
         return self.client.execute(query)
 
@@ -858,10 +831,7 @@ class SaagieApi:
         Parameters
         ----------
         pipeline_id : str
-            UUID of your pipeline. Can be found in the URL after the
-            '/pipeline' (eg: the pipeline UUID is
-            '4da29f25-e7c9-4410-869e-40b9ba0074d1' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/pipeline/4da29f25-e7c9-4410-869e-40b9ba0074d1)
+            UUID of your pipeline  (see README on how to find it)
 
         Returns
         -------
@@ -879,10 +849,7 @@ class SaagieApi:
         Parameters
         ----------
         pipeline_instance_id : str
-            UUID of your pipeline instance. Can be found in the URL after the
-            '/pipeline' (eg: the pipeline UUID is
-            'b26bebf1-46fe-481e-8fb7-ddd4d8cdd798' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/pipeline/4da29f25-e7c9-4410-869e-40b9ba0074d1/instances/b26bebf1-46fe-481e-8fb7-ddd4d8cdd798)
+            UUID of your pipeline instance  (see README on how to find it)
 
         Returns
         -------
@@ -903,10 +870,7 @@ class SaagieApi:
         Parameters
         ----------
         pipeline_id : str
-            UUID of your pipeline. Can be found in the URL after the
-            '/pipeline' (eg: the pipeline UUID is
-            '4da29f25-e7c9-4410-869e-40b9ba0074d1' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/pipeline/4da29f25-e7c9-4410-869e-40b9ba0074d1)
+            UUID of your pipeline  (see README on how to find it)
 
         Returns
         -------
@@ -924,10 +888,7 @@ class SaagieApi:
         Parameters
         ----------
         pipeline_id : str
-            UUID of your pipeline. Can be found in the URL after the
-            '/pipeline' (eg: the pipeline UUID is
-            '4da29f25-e7c9-4410-869e-40b9ba0074d1' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/pipeline/4da29f25-e7c9-4410-869e-40b9ba0074d1)
+            UUID of your pipeline  (see README on how to find it)
 
         Returns
         -------
@@ -946,10 +907,7 @@ class SaagieApi:
         Parameters
         ----------
         pipeline_id : str
-            UUID of your pipeline. Can be found in the URL after the
-            '/pipeline' (eg: the pipeline UUID is
-            '4da29f25-e7c9-4410-869e-40b9ba0074d1' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/pipeline/4da29f25-e7c9-4410-869e-40b9ba0074d1)
+            UUID of your pipeline  (see README on how to find it)
         freq : int, optional
             Number of seconds between 2 state checks
         timeout : int, optional
@@ -971,7 +929,7 @@ class SaagieApi:
         pipeline_instance_info = self.client.execute(query)
         state = pipeline_instance_info.get("pipelineInstance").get("status")
         sec = 0
-        to = False
+
         while state not in final_status_list:
             to = False if timeout == -1 else sec >= timeout
             if to:
@@ -993,12 +951,10 @@ class SaagieApi:
         name : str
             Name of the pipeline. Must not already exist in the project
         project_id : str
-            UUID of your project. Can be found in the project URL after the
-            '/project' (eg: the project UUID is
-            '8321e13c-892a-4481-8552-5be4b6cc5df4' in
-            https://saagie-workspace.prod.saagie.io/projects/platform/6/project/8321e13c-892a-4481-8552-5be4b6cc5df4/jobs)
+            UUID of your project (see README on how to find it)
         jobs_id : List
-            Ordered list of job's id (example : ["id1", "id2", "id3"] will result in the following pipeline id1 -> id2 -> id3)
+            Ordered list of job's id (example : ["id1", "id2", "id3"]
+            will result in the following pipeline id1 -> id2 -> id3)
         description : str, optional
             Description of the pipeline
 
